@@ -13,8 +13,8 @@ from mathy_core.rules import (
     ConstantsSimplifyRule,
     DistributiveFactorOutRule,
     DistributiveMultiplyRule,
-    VariableMultiplyRule,
     RestateSubtractionRule,
+    VariableMultiplyRule,
 )
 from mathy_core.tree import BinaryTreeNode, VisitStop
 from mathy_core.util import compare_expression_string_values, raise_with_history
@@ -272,7 +272,7 @@ class MathyEnv:
         )
 
     def get_next_state(
-        self, env_state: MathyEnvState, action: Union[int, ActionType]
+        self, env_state: MathyEnvState, action: Union[int, np.int64, ActionType]
     ) -> Tuple[MathyEnvState, time_step.TimeStep, ExpressionChangeRule]:
         """
         # Parameters
@@ -362,7 +362,8 @@ class MathyEnv:
         print(
             self.render_state(
                 env_state, action_name, token_index, change, change_reward, pretty
-            )
+            ),
+            flush=True,
         )
 
     def is_terminal_state(self, env_state: MathyEnvState) -> bool:
@@ -597,7 +598,7 @@ class MathyEnv:
         """Convert env_state to a string for MCTS cache"""
         return env_state.agent.problem
 
-    def to_action(self, action: Union[int, ActionType]) -> ActionType:
+    def to_action(self, action: Union[int, np.int64, ActionType]) -> ActionType:
         """Resolve a given action input to a tuple of (rule_index, node_index).
 
         When given an int, it is treated as an index into the flattened 2d action
@@ -606,4 +607,4 @@ class MathyEnv:
             return action
         token_index = action % self.max_seq_len
         action_index = int((action - token_index) / self.max_seq_len)
-        return action_index, token_index
+        return action_index, int(token_index)
