@@ -1,7 +1,7 @@
 from typing import Optional
 
 import numpy as np
-from gym import spaces
+from gymnasium import spaces
 
 
 class MaskedDiscrete(spaces.Discrete):
@@ -19,7 +19,7 @@ class MaskedDiscrete(spaces.Discrete):
         super(MaskedDiscrete, self).__init__(n)  # type:ignore
         self.update_mask(mask)
 
-    def sample(self, mask: Optional[np.ndarray] = None) -> int:
+    def sample(self, mask: Optional[np.ndarray] = None) -> np.int64:
         mask = self.mask if mask is None else mask
         probability = self.mask / np.sum(self.mask)
         return self.np_random.choice(self.n, p=probability)
