@@ -1,11 +1,12 @@
 from typing import Any, Dict, Optional, Tuple, Type, Union
 
-import gym
+import gymnasium as gym
 import numpy as np
-from gym import error as gym_error
-from gym import spaces
-from gym.envs.registration import register
+from gymnasium import error as gym_error
+from gymnasium import spaces
+from gymnasium.envs.registration import register
 from mathy_core.rule import ExpressionChangeRule
+from numpy.typing import NDArray
 
 from ..env import MathyEnv
 from ..state import MathyEnvState
@@ -14,7 +15,7 @@ from ..types import ActionType, MathyEnvProblemArgs
 from .masked_discrete import MaskedDiscrete
 
 
-class MathyGymEnv(gym.Env):
+class MathyGymEnv(gym.Env[NDArray[Any], np.int64]):
     """A small wrapper around Mathy envs to allow them to work with OpenAI Gym. The
     agents currently use this env wrapper, but it could be dropped in the future."""
 
@@ -49,7 +50,7 @@ class MathyGymEnv(gym.Env):
         else:
             self._challenge, _ = self.mathy.get_initial_state(env_problem_args)
 
-        self.action_space = MaskedDiscrete(
+        self.action_space = MaskedDiscrete(  # type:ignore
             self.action_size, np.array([1] * self.action_size)
         )
         mask = len(self.mathy.rules) * self.mathy.max_seq_len
@@ -59,7 +60,7 @@ class MathyGymEnv(gym.Env):
         time = 1
         obs_size = mask + values + nodes + type + time
         self.observation_space = spaces.Box(
-            low=0, high=1, shape=(obs_size,), dtype=float
+            low=0, high=1, shape=(obs_size,), dtype=np.float32
         )
 
     @property
@@ -67,21 +68,25 @@ class MathyGymEnv(gym.Env):
         return self.mathy.action_size
 
     def step(
-        self, action: Union[int, ActionType]
-    ) -> Tuple[np.ndarray, Any, bool, Dict[str, object]]:
+        self, action: Union[int, np.int64, ActionType]
+    ) -> Tuple[np.ndarray, Any, bool, bool, Dict[str, object]]:
         assert self.state is not None, "call reset() before stepping the environment"
         self.state, transition, change = self.mathy.get_next_state(self.state, action)
-        done = is_terminal_transition(transition)
+        terminated = is_terminal_transition(transition)
+        truncated = self.state.agent.moves_remaining <= 0
         info = {
             "transition": transition,
-            "done": done,
+            "done": terminated,
+            "truncated": truncated,
             "valid": change.result is not None,
         }
-        if done:
+        if terminated or truncated:
             info["win"] = transition.reward > 0.0
-        return self._observe(self.state), transition.reward, done, info
 
-    def _observe(self, state: MathyEnvState) -> np.ndarray:
+        obs, _ = self._observe(self.state)
+        return obs, transition.reward, terminated, truncated, info
+
+    def _observe(self, state: MathyEnvState) -> Tuple[np.ndarray, dict]:
         """Observe the environment at the given state, updating the observation
         space and action space for the given state."""
         action_mask = self.mathy.get_valid_moves(state)
@@ -96,21 +101,22 @@ class MathyGymEnv(gym.Env):
                 flat_mask = flat_mask / mask_sum
         nodes = np.array(observation.nodes, dtype="float32").reshape(-1)
         values = np.array(observation.values, dtype="float32").reshape(-1)
-        np_observation = np.concatenate(
+        obs = np.concatenate(
             np.array(
                 [observation.type, observation.time, nodes, values, flat_mask],
                 dtype="object",
             ),
             axis=-1,
+            dtype="float32",
         )
-        return np_observation
+        return obs, {}
 
     def reset(
         self,
+        *,
         seed: Optional[int] = None,
-        return_info: bool = False,
-        options: Optional[Dict[Any, Any]] = None,
-    ) -> Union[Any, Tuple[Any, Dict[Any, Any]]]:
+        options: Optional[Dict[str, Any]] = None,
+    ) -> Tuple[Any, Dict[Any, Any]]:
         if self.state is not None:
             self.mathy.finalize_state(self.state)
         if self.repeat_problem:
@@ -122,7 +128,9 @@ class MathyGymEnv(gym.Env):
             )
         return self._observe(self.state)
 
-    def reset_with_input(self, problem_text: str, max_moves: int = 16) -> np.ndarray:
+    def reset_with_input(
+        self, problem_text: str, max_moves: int = 16
+    ) -> Tuple[np.ndarray, dict]:
         # If the episode is being reset because it ended, assert the validity
         # of the last problem outcome
         if self.state is not None:
