@@ -58,11 +58,11 @@ class MathyObservation(NamedTuple):
 
 
 # fmt: off
-MathyObservation.nodes.__doc__ = "tree node types in the current environment state shape=[n,]" # noqa
-MathyObservation.mask.__doc__ = "0/1 mask where 0 indicates an invalid action shape=[n,]" # noqa
-MathyObservation.values.__doc__ = "tree node value sequences, with non number indices set to 0.0 shape=[n,]" # noqa
-MathyObservation.type.__doc__ = "two column hash of problem environment type shape=[2,]" # noqa
-MathyObservation.time.__doc__ = "float value between 0.0 and 1.0 indicating the time elapsed shape=[1,]" # noqa
+MathyObservation.nodes.__doc__ = "tree node types in the current environment state shape=[n,]"  # noqa
+MathyObservation.mask.__doc__ = "0/1 mask where 0 indicates an invalid action shape=[n,]"  # noqa
+MathyObservation.values.__doc__ = "tree node value sequences, with non number indices set to 0.0 shape=[n,]"  # noqa
+MathyObservation.type.__doc__ = "two column hash of problem environment type shape=[2,]"  # noqa
+MathyObservation.time.__doc__ = "float value between 0.0 and 1.0 indicating the time elapsed shape=[1,]"  # noqa
 # fmt: on
 
 
@@ -75,8 +75,8 @@ class MathyEnvStateStep(NamedTuple):
 
 
 # fmt: off
-MathyEnvStateStep.raw.__doc__ = "the input text at the timestep" # noqa
-MathyEnvStateStep.action.__doc__ = "a tuple indicating the chosen action and the node it was applied to" # noqa
+MathyEnvStateStep.raw.__doc__ = "the input text at the timestep"  # noqa
+MathyEnvStateStep.action.__doc__ = "a tuple indicating the chosen action and the node it was applied to"  # noqa
 # fmt: on
 
 
@@ -193,13 +193,14 @@ class MathyEnvState(object):
             # The adler32 crc is used in zip files and is determinstic
             # across runs while also being fast to calculate. It is NOT
             # cryptographically secure.
-            hashes = np.asfarray(
+            hashes = np.asarray(
                 [
                     adler32(type_str.encode(encoding="utf-8")),
                     adler32(type_str[::-1].encode(encoding="utf-8")),
                     adler32(type_str.upper().encode(encoding="utf-8")),
                     adler32(type_str.replace(".", "").encode(encoding="utf-8")),
-                ]
+                ],
+                dtype=np.float32,
             )
             if hashes.sum() != 0.0:
                 hashes = (hashes - min(hashes)) / (max(hashes) - min(hashes))
@@ -240,11 +241,11 @@ class MathyEnvState(object):
         # The "types" and "values" can be normalized 0-1
         if normalize is True:
             # https://bit.ly/3irAalH
-            x = np.asfarray(values)
+            x = np.asarray(values, dtype=np.float32)
             if x.sum() != 0.0:
                 x = (x - min(x)) / (max(x) - min(x) + 1e-32)
             values = x.tolist()
-            x = np.asfarray(vectors)
+            x = np.asarray(vectors, dtype=np.float32)
             if x.sum() != 0.0:
                 x = (x - min(x)) / (max(x) - min(x) + 1e-32)
             vectors = x.tolist()
